@@ -11,7 +11,10 @@ Async module
 from logging import getLogger
 from types import FunctionType
 
-import pycurl
+try:
+    import pycurl2 as pycurl
+except ImportError:
+    import pycurl
 
 # Lib imports
 from . import get_version
@@ -199,10 +202,10 @@ class AsyncClient(object):
         opener.fail_callback = None
         opener.request = None
 
-        ## if getattr(opener, "dirty", False) is True:
-        ##     # After appling this method curl raise error
-        ##     # Unable to fetch curl handle from curl object
-        ##     #opener.reset()
+        if getattr(opener, "dirty", False) is True:
+            # After appling this method curl raise error
+            # Unable to fetch curl handle from curl object
+            opener.reset()
 
         # Maybe need delete cookies?
         return opener
