@@ -17,9 +17,8 @@ __all__ = ("HTTPError", "InvalidMethod", "CurlError", "InterfaceError")
 class HTTPError(Exception):
     """Exception for failed HTTP request
 
-    Attributes:
-
-    - `code`: HTTP error integer error code, e. g. 404
+    :param code: HTTP error integer error code, e. g. 404
+    :param message: error message string
     """
     def __init__(self, code, message=None):
         self.code = code
@@ -32,6 +31,9 @@ class InvalidMethod(Exception):
 
 class CurlError(Exception):
     """Exception raise when `pycurl.Curl` raise connection errors
+
+    :param code: HTTP error integer error code, e. g. 404
+    :param message: error message string
     """
     def __init__(self, code, message=None):
         self.code = code
@@ -43,7 +45,6 @@ class InterfaceError(Exception):
     or not allowed parameter
     """
 
-
 class AuthError(Exception):
     """Raised by auth manager
     """
